Exception: Spotify::Errors::InitializationObjectDuplicationError
- Inherits:
-
StandardError
- Object
- StandardError
- Spotify::Errors::InitializationObjectDuplicationError
- Defined in:
- lib/spotify/sdk/initialization.rb
Overview
A Error class for when the initialization subject matches against multiple selectors. When this Error occurs, this becomes an internal bug. It should be filed on the GitHub issue tracker.